from __future__ import annotations

from typing import Any

import datasets

from mteb.abstasks.AbsTaskBitextMining import AbsTaskBitextMining
from mteb.abstasks.MultilingualTask import MultilingualTask
from mteb.abstasks.TaskMetadata import TaskMetadata

_LANGUAGES = [
    "asm_Beng",
    "ben_Beng",
    "brx_Deva",
    "doi_Deva",
    "eng_Latn",
    "gom_Deva",
    "guj_Gujr",
    "hin_Deva",
    "kan_Knda",
    "kas_Arab",
    "mai_Deva",
    "mal_Mlym",
    "mar_Deva",
    "mni_Mtei",
    "npi_Deva",
    "ory_Orya",
    "pan_Guru",
    "san_Deva",
    "sat_Olck",
    "snd_Deva",
    "tam_Taml",
    "tel_Telu",
    "urd_Arab",
]
_SPLIT = ["test"]


def extend_lang_pairs() -> dict[str, list[str]]:
    # add all possible language pairs
    hf_lang_subset2isolang = {}
    for x in _LANGUAGES:
        for y in _LANGUAGES:
            if x != y:
                pair = f"{x}-{y}"
                hf_lang_subset2isolang[pair] = [
                    x.replace("_", "-"),
                    y.replace("_", "-"),
                ]
    return hf_lang_subset2isolang


_LANGUAGES_MAPPING = extend_lang_pairs()


def get_hash(text):
    """Get hash of text field."""
    return {"hash": hash(text)}


def check_uniques(example, uniques):
    """Check if current hash is still in set of unique hashes and remove if true."""
    if example["hash"] in uniques:
        uniques.remove(example["hash"])
        return True
    else:
        return False


class IN22ConvBitextMining(AbsTaskBitextMining, MultilingualTask):
    parallel_subsets = True
    metadata = TaskMetadata(
        name="IN22ConvBitextMining",
        dataset={
            "path": "mteb/IN22-Conv",
            "revision": "16f46f059d56eac7c65c3c9581a45e40199eb140",
            "trust_remote_code": True,
        },
        description="IN22-Conv is a n-way parallel conversation domain benchmark dataset for machine translation spanning English and 22 Indic languages.",
        reference="https://huggingface.co/datasets/ai4bharat/IN22-Conv",
        type="BitextMining",
        category="s2s",
        modalities=["text"],
        eval_splits=_SPLIT,
        eval_langs=_LANGUAGES_MAPPING,
        main_score="f1",
        date=("2022-10-01", "2023-03-01"),
        domains=["Social", "Spoken", "Fiction", "Spoken"],
        task_subtypes=[],
        license="cc-by-4.0",
        annotations_creators="expert-annotated",
        dialect=[],
        sample_creation="created",
        bibtex_citation="""@article{gala2023indictrans,
title={IndicTrans2: Towards High-Quality and Accessible Machine Translation Models for all 22 Scheduled Indian Languages},
author={Jay Gala and Pranjal A Chitale and A K Raghavan and Varun Gumma and Sumanth Doddapaneni and Aswanth Kumar M and Janki Atul Nawale and Anupama Sujatha and Ratish Puduppully and Vivek Raghavan and Pratyush Kumar and Mitesh M Khapra and Raj Dabre and Anoop Kunchukuttan},
journal={Transactions on Machine Learning Research},
issn={2835-8856},
year={2023},
url={https://openreview.net/forum?id=vfT4YuzAYA},
note={}
}""",
        descriptive_stats={
            "test": {
                "average_sentence1_length": 54.32948595562498,
                "average_sentence2_length": 54.32948595562498,
                "num_samples": 760518,
                "hf_subset_descriptive_stats": {
                    "asm_Beng-ben_Beng": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "asm_Beng-brx_Deva": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "asm_Beng-doi_Deva": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "asm_Beng-eng_Latn": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "asm_Beng-gom_Deva": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "asm_Beng-guj_Gujr": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "asm_Beng-hin_Deva": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "asm_Beng-kan_Knda": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "asm_Beng-kas_Arab": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "asm_Beng-mai_Deva": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "asm_Beng-mal_Mlym": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "asm_Beng-mar_Deva": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "asm_Beng-mni_Mtei": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "asm_Beng-npi_Deva": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "asm_Beng-ory_Orya": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "asm_Beng-pan_Guru": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "asm_Beng-san_Deva": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "asm_Beng-sat_Olck": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "asm_Beng-snd_Deva": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "asm_Beng-tam_Taml": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "asm_Beng-tel_Telu": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "asm_Beng-urd_Arab": {
                        "average_sentence1_length": 53.753825681969396,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "ben_Beng-asm_Beng": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "ben_Beng-brx_Deva": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "ben_Beng-doi_Deva": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "ben_Beng-eng_Latn": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "ben_Beng-gom_Deva": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "ben_Beng-guj_Gujr": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "ben_Beng-hin_Deva": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "ben_Beng-kan_Knda": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "ben_Beng-kas_Arab": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "ben_Beng-mai_Deva": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "ben_Beng-mal_Mlym": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "ben_Beng-mar_Deva": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "ben_Beng-mni_Mtei": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "ben_Beng-npi_Deva": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "ben_Beng-ory_Orya": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "ben_Beng-pan_Guru": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "ben_Beng-san_Deva": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "ben_Beng-sat_Olck": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "ben_Beng-snd_Deva": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "ben_Beng-tam_Taml": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "ben_Beng-tel_Telu": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "ben_Beng-urd_Arab": {
                        "average_sentence1_length": 50.03060545575516,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "brx_Deva-asm_Beng": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "brx_Deva-ben_Beng": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "brx_Deva-doi_Deva": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "brx_Deva-eng_Latn": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "brx_Deva-gom_Deva": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "brx_Deva-guj_Gujr": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "brx_Deva-hin_Deva": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "brx_Deva-kan_Knda": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "brx_Deva-kas_Arab": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "brx_Deva-mai_Deva": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "brx_Deva-mal_Mlym": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "brx_Deva-mar_Deva": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "brx_Deva-mni_Mtei": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "brx_Deva-npi_Deva": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "brx_Deva-ory_Orya": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "brx_Deva-pan_Guru": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "brx_Deva-san_Deva": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "brx_Deva-sat_Olck": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "brx_Deva-snd_Deva": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "brx_Deva-tam_Taml": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "brx_Deva-tel_Telu": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "brx_Deva-urd_Arab": {
                        "average_sentence1_length": 54.05988023952096,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "doi_Deva-asm_Beng": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "doi_Deva-ben_Beng": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "doi_Deva-brx_Deva": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "doi_Deva-eng_Latn": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "doi_Deva-gom_Deva": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "doi_Deva-guj_Gujr": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "doi_Deva-hin_Deva": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "doi_Deva-kan_Knda": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "doi_Deva-kas_Arab": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "doi_Deva-mai_Deva": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "doi_Deva-mal_Mlym": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "doi_Deva-mar_Deva": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "doi_Deva-mni_Mtei": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "doi_Deva-npi_Deva": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "doi_Deva-ory_Orya": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "doi_Deva-pan_Guru": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "doi_Deva-san_Deva": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "doi_Deva-sat_Olck": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "doi_Deva-snd_Deva": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "doi_Deva-tam_Taml": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "doi_Deva-tel_Telu": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "doi_Deva-urd_Arab": {
                        "average_sentence1_length": 57.37857618097139,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "eng_Latn-asm_Beng": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "eng_Latn-ben_Beng": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "eng_Latn-brx_Deva": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "eng_Latn-doi_Deva": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "eng_Latn-gom_Deva": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "eng_Latn-guj_Gujr": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "eng_Latn-hin_Deva": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "eng_Latn-kan_Knda": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "eng_Latn-kas_Arab": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "eng_Latn-mai_Deva": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "eng_Latn-mal_Mlym": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "eng_Latn-mar_Deva": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "eng_Latn-mni_Mtei": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "eng_Latn-npi_Deva": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "eng_Latn-ory_Orya": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "eng_Latn-pan_Guru": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "eng_Latn-san_Deva": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "eng_Latn-sat_Olck": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "eng_Latn-snd_Deva": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "eng_Latn-tam_Taml": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "eng_Latn-tel_Telu": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "eng_Latn-urd_Arab": {
                        "average_sentence1_length": 53.17631403858949,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "gom_Deva-asm_Beng": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "gom_Deva-ben_Beng": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "gom_Deva-brx_Deva": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "gom_Deva-doi_Deva": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "gom_Deva-eng_Latn": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "gom_Deva-guj_Gujr": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "gom_Deva-hin_Deva": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "gom_Deva-kan_Knda": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "gom_Deva-kas_Arab": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "gom_Deva-mai_Deva": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "gom_Deva-mal_Mlym": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "gom_Deva-mar_Deva": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "gom_Deva-mni_Mtei": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "gom_Deva-npi_Deva": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "gom_Deva-ory_Orya": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "gom_Deva-pan_Guru": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "gom_Deva-san_Deva": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "gom_Deva-sat_Olck": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "gom_Deva-snd_Deva": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "gom_Deva-tam_Taml": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "gom_Deva-tel_Telu": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "gom_Deva-urd_Arab": {
                        "average_sentence1_length": 50.22621423819029,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-asm_Beng": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-ben_Beng": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-brx_Deva": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-doi_Deva": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-eng_Latn": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-gom_Deva": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-hin_Deva": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-kan_Knda": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-kas_Arab": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-mai_Deva": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-mal_Mlym": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-mar_Deva": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-mni_Mtei": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-npi_Deva": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-ory_Orya": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-pan_Guru": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-san_Deva": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-sat_Olck": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-snd_Deva": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-tam_Taml": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-tel_Telu": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "guj_Gujr-urd_Arab": {
                        "average_sentence1_length": 51.54823685961411,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "hin_Deva-asm_Beng": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "hin_Deva-ben_Beng": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "hin_Deva-brx_Deva": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "hin_Deva-doi_Deva": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "hin_Deva-eng_Latn": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "hin_Deva-gom_Deva": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "hin_Deva-guj_Gujr": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "hin_Deva-kan_Knda": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "hin_Deva-kas_Arab": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "hin_Deva-mai_Deva": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "hin_Deva-mal_Mlym": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "hin_Deva-mar_Deva": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "hin_Deva-mni_Mtei": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "hin_Deva-npi_Deva": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "hin_Deva-ory_Orya": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "hin_Deva-pan_Guru": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "hin_Deva-san_Deva": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "hin_Deva-sat_Olck": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "hin_Deva-snd_Deva": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "hin_Deva-tam_Taml": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "hin_Deva-tel_Telu": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "hin_Deva-urd_Arab": {
                        "average_sentence1_length": 52.67598137059215,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "kan_Knda-asm_Beng": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "kan_Knda-ben_Beng": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "kan_Knda-brx_Deva": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "kan_Knda-doi_Deva": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "kan_Knda-eng_Latn": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "kan_Knda-gom_Deva": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "kan_Knda-guj_Gujr": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "kan_Knda-hin_Deva": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "kan_Knda-kas_Arab": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "kan_Knda-mai_Deva": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "kan_Knda-mal_Mlym": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "kan_Knda-mar_Deva": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "kan_Knda-mni_Mtei": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "kan_Knda-npi_Deva": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "kan_Knda-ory_Orya": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "kan_Knda-pan_Guru": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "kan_Knda-san_Deva": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "kan_Knda-sat_Olck": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "kan_Knda-snd_Deva": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "kan_Knda-tam_Taml": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "kan_Knda-tel_Telu": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "kan_Knda-urd_Arab": {
                        "average_sentence1_length": 56.14437791084497,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "kas_Arab-asm_Beng": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "kas_Arab-ben_Beng": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "kas_Arab-brx_Deva": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "kas_Arab-doi_Deva": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "kas_Arab-eng_Latn": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "kas_Arab-gom_Deva": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "kas_Arab-guj_Gujr": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "kas_Arab-hin_Deva": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "kas_Arab-kan_Knda": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "kas_Arab-mai_Deva": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "kas_Arab-mal_Mlym": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "kas_Arab-mar_Deva": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "kas_Arab-mni_Mtei": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "kas_Arab-npi_Deva": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "kas_Arab-ory_Orya": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "kas_Arab-pan_Guru": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "kas_Arab-san_Deva": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "kas_Arab-sat_Olck": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "kas_Arab-snd_Deva": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "kas_Arab-tam_Taml": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "kas_Arab-tel_Telu": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "kas_Arab-urd_Arab": {
                        "average_sentence1_length": 55.81437125748503,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "mai_Deva-asm_Beng": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "mai_Deva-ben_Beng": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "mai_Deva-brx_Deva": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "mai_Deva-doi_Deva": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "mai_Deva-eng_Latn": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "mai_Deva-gom_Deva": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "mai_Deva-guj_Gujr": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "mai_Deva-hin_Deva": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "mai_Deva-kan_Knda": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "mai_Deva-kas_Arab": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "mai_Deva-mal_Mlym": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "mai_Deva-mar_Deva": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "mai_Deva-mni_Mtei": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "mai_Deva-npi_Deva": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "mai_Deva-ory_Orya": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "mai_Deva-pan_Guru": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "mai_Deva-san_Deva": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "mai_Deva-sat_Olck": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "mai_Deva-snd_Deva": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "mai_Deva-tam_Taml": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "mai_Deva-tel_Telu": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "mai_Deva-urd_Arab": {
                        "average_sentence1_length": 54.3020625415835,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-asm_Beng": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-ben_Beng": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-brx_Deva": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-doi_Deva": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-eng_Latn": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-gom_Deva": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-guj_Gujr": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-hin_Deva": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-kan_Knda": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-kas_Arab": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-mai_Deva": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-mar_Deva": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-mni_Mtei": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-npi_Deva": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-ory_Orya": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-pan_Guru": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-san_Deva": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-sat_Olck": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-snd_Deva": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-tam_Taml": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-tel_Telu": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "mal_Mlym-urd_Arab": {
                        "average_sentence1_length": 61.24151696606786,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "mar_Deva-asm_Beng": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "mar_Deva-ben_Beng": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "mar_Deva-brx_Deva": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "mar_Deva-doi_Deva": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "mar_Deva-eng_Latn": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "mar_Deva-gom_Deva": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "mar_Deva-guj_Gujr": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "mar_Deva-hin_Deva": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "mar_Deva-kan_Knda": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "mar_Deva-kas_Arab": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "mar_Deva-mai_Deva": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "mar_Deva-mal_Mlym": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "mar_Deva-mni_Mtei": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "mar_Deva-npi_Deva": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "mar_Deva-ory_Orya": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "mar_Deva-pan_Guru": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "mar_Deva-san_Deva": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "mar_Deva-sat_Olck": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "mar_Deva-snd_Deva": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "mar_Deva-tam_Taml": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "mar_Deva-tel_Telu": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "mar_Deva-urd_Arab": {
                        "average_sentence1_length": 54.52761144377911,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-asm_Beng": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-ben_Beng": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-brx_Deva": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-doi_Deva": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-eng_Latn": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-gom_Deva": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-guj_Gujr": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-hin_Deva": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-kan_Knda": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-kas_Arab": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-mai_Deva": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-mal_Mlym": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-mar_Deva": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-npi_Deva": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-ory_Orya": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-pan_Guru": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-san_Deva": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-sat_Olck": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-snd_Deva": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-tam_Taml": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-tel_Telu": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "mni_Mtei-urd_Arab": {
                        "average_sentence1_length": 50.91417165668663,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "npi_Deva-asm_Beng": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "npi_Deva-ben_Beng": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "npi_Deva-brx_Deva": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "npi_Deva-doi_Deva": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "npi_Deva-eng_Latn": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "npi_Deva-gom_Deva": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "npi_Deva-guj_Gujr": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "npi_Deva-hin_Deva": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "npi_Deva-kan_Knda": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "npi_Deva-kas_Arab": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "npi_Deva-mai_Deva": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "npi_Deva-mal_Mlym": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "npi_Deva-mar_Deva": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "npi_Deva-mni_Mtei": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "npi_Deva-ory_Orya": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "npi_Deva-pan_Guru": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "npi_Deva-san_Deva": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "npi_Deva-sat_Olck": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "npi_Deva-snd_Deva": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "npi_Deva-tam_Taml": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "npi_Deva-tel_Telu": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "npi_Deva-urd_Arab": {
                        "average_sentence1_length": 53.30272787757818,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "ory_Orya-asm_Beng": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "ory_Orya-ben_Beng": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "ory_Orya-brx_Deva": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "ory_Orya-doi_Deva": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "ory_Orya-eng_Latn": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "ory_Orya-gom_Deva": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "ory_Orya-guj_Gujr": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "ory_Orya-hin_Deva": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "ory_Orya-kan_Knda": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "ory_Orya-kas_Arab": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "ory_Orya-mai_Deva": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "ory_Orya-mal_Mlym": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "ory_Orya-mar_Deva": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "ory_Orya-mni_Mtei": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "ory_Orya-npi_Deva": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "ory_Orya-pan_Guru": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "ory_Orya-san_Deva": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "ory_Orya-sat_Olck": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "ory_Orya-snd_Deva": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "ory_Orya-tam_Taml": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "ory_Orya-tel_Telu": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "ory_Orya-urd_Arab": {
                        "average_sentence1_length": 55.509647371922824,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "pan_Guru-asm_Beng": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "pan_Guru-ben_Beng": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "pan_Guru-brx_Deva": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "pan_Guru-doi_Deva": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "pan_Guru-eng_Latn": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "pan_Guru-gom_Deva": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "pan_Guru-guj_Gujr": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "pan_Guru-hin_Deva": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "pan_Guru-kan_Knda": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "pan_Guru-kas_Arab": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "pan_Guru-mai_Deva": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "pan_Guru-mal_Mlym": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "pan_Guru-mar_Deva": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "pan_Guru-mni_Mtei": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "pan_Guru-npi_Deva": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "pan_Guru-ory_Orya": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "pan_Guru-san_Deva": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "pan_Guru-sat_Olck": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "pan_Guru-snd_Deva": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "pan_Guru-tam_Taml": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "pan_Guru-tel_Telu": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "pan_Guru-urd_Arab": {
                        "average_sentence1_length": 52.83366600133067,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "san_Deva-asm_Beng": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "san_Deva-ben_Beng": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "san_Deva-brx_Deva": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "san_Deva-doi_Deva": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "san_Deva-eng_Latn": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "san_Deva-gom_Deva": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "san_Deva-guj_Gujr": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "san_Deva-hin_Deva": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "san_Deva-kan_Knda": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "san_Deva-kas_Arab": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "san_Deva-mai_Deva": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "san_Deva-mal_Mlym": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "san_Deva-mar_Deva": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "san_Deva-mni_Mtei": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "san_Deva-npi_Deva": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "san_Deva-ory_Orya": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "san_Deva-pan_Guru": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "san_Deva-sat_Olck": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "san_Deva-snd_Deva": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "san_Deva-tam_Taml": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "san_Deva-tel_Telu": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "san_Deva-urd_Arab": {
                        "average_sentence1_length": 51.4311377245509,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "sat_Olck-asm_Beng": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "sat_Olck-ben_Beng": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "sat_Olck-brx_Deva": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "sat_Olck-doi_Deva": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "sat_Olck-eng_Latn": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "sat_Olck-gom_Deva": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "sat_Olck-guj_Gujr": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "sat_Olck-hin_Deva": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "sat_Olck-kan_Knda": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "sat_Olck-kas_Arab": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "sat_Olck-mai_Deva": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "sat_Olck-mal_Mlym": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "sat_Olck-mar_Deva": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "sat_Olck-mni_Mtei": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "sat_Olck-npi_Deva": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "sat_Olck-ory_Orya": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "sat_Olck-pan_Guru": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "sat_Olck-san_Deva": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "sat_Olck-snd_Deva": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "sat_Olck-tam_Taml": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "sat_Olck-tel_Telu": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "sat_Olck-urd_Arab": {
                        "average_sentence1_length": 58.94011976047904,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "snd_Deva-asm_Beng": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "snd_Deva-ben_Beng": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "snd_Deva-brx_Deva": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "snd_Deva-doi_Deva": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "snd_Deva-eng_Latn": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "snd_Deva-gom_Deva": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "snd_Deva-guj_Gujr": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "snd_Deva-hin_Deva": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "snd_Deva-kan_Knda": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "snd_Deva-kas_Arab": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "snd_Deva-mai_Deva": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "snd_Deva-mal_Mlym": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "snd_Deva-mar_Deva": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "snd_Deva-mni_Mtei": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "snd_Deva-npi_Deva": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "snd_Deva-ory_Orya": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "snd_Deva-pan_Guru": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "snd_Deva-san_Deva": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "snd_Deva-sat_Olck": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "snd_Deva-tam_Taml": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "snd_Deva-tel_Telu": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "snd_Deva-urd_Arab": {
                        "average_sentence1_length": 54.445109780439125,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "tam_Taml-asm_Beng": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "tam_Taml-ben_Beng": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "tam_Taml-brx_Deva": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "tam_Taml-doi_Deva": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "tam_Taml-eng_Latn": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "tam_Taml-gom_Deva": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "tam_Taml-guj_Gujr": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "tam_Taml-hin_Deva": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "tam_Taml-kan_Knda": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "tam_Taml-kas_Arab": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "tam_Taml-mai_Deva": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "tam_Taml-mal_Mlym": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "tam_Taml-mar_Deva": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "tam_Taml-mni_Mtei": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "tam_Taml-npi_Deva": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "tam_Taml-ory_Orya": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "tam_Taml-pan_Guru": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "tam_Taml-san_Deva": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "tam_Taml-sat_Olck": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "tam_Taml-snd_Deva": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "tam_Taml-tel_Telu": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                    "tam_Taml-urd_Arab": {
                        "average_sentence1_length": 62.590818363273456,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "tel_Telu-asm_Beng": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "tel_Telu-ben_Beng": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "tel_Telu-brx_Deva": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "tel_Telu-doi_Deva": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "tel_Telu-eng_Latn": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "tel_Telu-gom_Deva": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "tel_Telu-guj_Gujr": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "tel_Telu-hin_Deva": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "tel_Telu-kan_Knda": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "tel_Telu-kas_Arab": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "tel_Telu-mai_Deva": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "tel_Telu-mal_Mlym": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "tel_Telu-mar_Deva": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "tel_Telu-mni_Mtei": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "tel_Telu-npi_Deva": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "tel_Telu-ory_Orya": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "tel_Telu-pan_Guru": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "tel_Telu-san_Deva": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "tel_Telu-sat_Olck": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "tel_Telu-snd_Deva": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "tel_Telu-tam_Taml": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "tel_Telu-urd_Arab": {
                        "average_sentence1_length": 51.16300731869594,
                        "average_sentence2_length": 53.568196939454424,
                        "num_samples": 1503,
                    },
                    "urd_Arab-asm_Beng": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 53.753825681969396,
                        "num_samples": 1503,
                    },
                    "urd_Arab-ben_Beng": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 50.03060545575516,
                        "num_samples": 1503,
                    },
                    "urd_Arab-brx_Deva": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 54.05988023952096,
                        "num_samples": 1503,
                    },
                    "urd_Arab-doi_Deva": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 57.37857618097139,
                        "num_samples": 1503,
                    },
                    "urd_Arab-eng_Latn": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 53.17631403858949,
                        "num_samples": 1503,
                    },
                    "urd_Arab-gom_Deva": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 50.22621423819029,
                        "num_samples": 1503,
                    },
                    "urd_Arab-guj_Gujr": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 51.54823685961411,
                        "num_samples": 1503,
                    },
                    "urd_Arab-hin_Deva": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 52.67598137059215,
                        "num_samples": 1503,
                    },
                    "urd_Arab-kan_Knda": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 56.14437791084497,
                        "num_samples": 1503,
                    },
                    "urd_Arab-kas_Arab": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 55.81437125748503,
                        "num_samples": 1503,
                    },
                    "urd_Arab-mai_Deva": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 54.3020625415835,
                        "num_samples": 1503,
                    },
                    "urd_Arab-mal_Mlym": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 61.24151696606786,
                        "num_samples": 1503,
                    },
                    "urd_Arab-mar_Deva": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 54.52761144377911,
                        "num_samples": 1503,
                    },
                    "urd_Arab-mni_Mtei": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 50.91417165668663,
                        "num_samples": 1503,
                    },
                    "urd_Arab-npi_Deva": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 53.30272787757818,
                        "num_samples": 1503,
                    },
                    "urd_Arab-ory_Orya": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 55.509647371922824,
                        "num_samples": 1503,
                    },
                    "urd_Arab-pan_Guru": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 52.83366600133067,
                        "num_samples": 1503,
                    },
                    "urd_Arab-san_Deva": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 51.4311377245509,
                        "num_samples": 1503,
                    },
                    "urd_Arab-sat_Olck": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 58.94011976047904,
                        "num_samples": 1503,
                    },
                    "urd_Arab-snd_Deva": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 54.445109780439125,
                        "num_samples": 1503,
                    },
                    "urd_Arab-tam_Taml": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 62.590818363273456,
                        "num_samples": 1503,
                    },
                    "urd_Arab-tel_Telu": {
                        "average_sentence1_length": 53.568196939454424,
                        "average_sentence2_length": 51.16300731869594,
                        "num_samples": 1503,
                    },
                },
            }
        },
    )

    def load_data(self, **kwargs: Any) -> None:
        """Load dataset from HuggingFace hub"""
        if self.data_loaded:
            return
        self.dataset = datasets.load_dataset(**self.metadata_dict["dataset"])
        self.data_loaded = True



from __future__ import annotations

import logging
from typing import Any

from ..evaluation.evaluators import STSEvaluator
from ..load_results.mteb_results import ScoresDict
from .AbsTask import AbsTask, DescriptiveStatistics

logger = logging.getLogger(__name__)


class STSDescriptiveStatistics(DescriptiveStatistics):
    """Descriptive statistics for STS

    Attributes:
        num_samples: number of samples in the dataset.
        average_sentence1_len: Average length of sentence1
        average_sentence2_len: Average length of sentence2
        avg_score: Average score
    """

    num_samples: int
    average_sentence1_len: float
    average_sentence2_len: float
    avg_score: float


class AbsTaskSTS(AbsTask):
    """Abstract class for STS experiments.

    self.load_data() must generate a huggingface dataset with a split matching self.metadata_dict["eval_splits"], and assign it to self.dataset. It must contain the following columns::
        sentence1: str
        sentence2: str
        score: float
    """

    def __init__(self, **kwargs):
        super().__init__(**kwargs)

    @property
    def min_score(self) -> int:
        return self.metadata_dict["min_score"]

    @property
    def max_score(self) -> int:
        return self.metadata_dict["max_score"]

    def _evaluate_subset(
        self, model, data_split, *, encode_kwargs: dict[str, Any] = {}, **kwargs
    ) -> ScoresDict:
        def normalize(x):
            return (x - self.min_score) / (self.max_score - self.min_score)

        normalized_scores = list(map(normalize, data_split["score"]))
        evaluator = STSEvaluator(
            data_split["sentence1"],
            data_split["sentence2"],
            normalized_scores,
            task_name=self.metadata.name,
            **kwargs,
        )
        scores = evaluator(model, encode_kwargs=encode_kwargs)

        self._add_main_score(scores)
        return scores

    def _add_main_score(self, scores: ScoresDict) -> None:
        scores["main_score"] = scores[self.metadata.main_score]

    def _calculate_metrics_from_split(
        self, split: str, hf_subset: str | None = None, compute_overall: bool = False
    ) -> STSDescriptiveStatistics:
        if hf_subset:
            sentence1 = self.dataset[hf_subset][split]["sentence1"]
            sentence2 = self.dataset[hf_subset][split]["sentence2"]
            score = self.dataset[hf_subset][split]["score"]
        elif compute_overall:
            sentence1 = []
            sentence2 = []
            score = []
            for hf_subset in self.metadata.eval_langs:
                sentence1.extend(self.dataset[hf_subset][split]["sentence1"])
                sentence2.extend(self.dataset[hf_subset][split]["sentence2"])
                score.extend(self.dataset[hf_subset][split]["score"])
        else:
            sentence1 = self.dataset[split]["sentence1"]
            sentence2 = self.dataset[split]["sentence2"]
            score = self.dataset[split]["score"]

        total_sentence1_len = sum([len(s) for s in sentence1])
        total_sentence2_len = sum([len(s) for s in sentence2])
        avg_score = sum(score) / len(score)
        return STSDescriptiveStatistics(
            num_samples=len(sentence1),
            average_sentence1_len=total_sentence1_len / len(sentence1),
            average_sentence2_len=total_sentence2_len / len(sentence2),
            avg_score=avg_score,
        )



from __future__ import annotations

from mteb.abstasks.AbsTaskClassification import AbsTaskClassification
from mteb.abstasks.TaskMetadata import TaskMetadata


class SinhalaNewsSourceClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="SinhalaNewsSourceClassification",
        description="This dataset contains Sinhala news headlines extracted from 9 news sources (websites) (Sri Lanka Army, Dinamina, GossipLanka, Hiru, ITN, Lankapuwath, NewsLK, Newsfirst, World Socialist Web Site-Sinhala).",
        dataset={
            "path": "NLPC-UOM/Sinhala-News-Source-classification",
            "revision": "ac4d14eeb68efbef95e247542d4432ce674faeb1",
        },
        reference="https://huggingface.co/datasets/NLPC-UOM/Sinhala-News-Source-classification",
        type="Classification",
        category="s2s",
        modalities=["text"],
        eval_splits=["train"],
        eval_langs=["sin-Sinh"],
        main_score="accuracy",
        date=("2021-02-17", "2022-08-20"),
        domains=["News", "Written"],
        task_subtypes=["Topic classification"],
        license="mit",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation="""
            @article{dhananjaya2022,
            author    = {Dhananjaya et al.},
            title     = {BERTifying Sinhala - A Comprehensive Analysis of Pre-trained Language Models for Sinhala Text Classification},
            journal   = {Year of Publication},
            year      = {2022},
            }""",
        descriptive_stats={
            "n_samples": {"train": 24094},
            "avg_character_length": {"train": 56.08},
        },
    )

    def dataset_transform(self):
        self.dataset = self.dataset.rename_column("comment", "text")
        self.dataset = self.stratified_subsampling(
            self.dataset, seed=self.seed, splits=["train"]
        )



from __future__ import annotations

from mteb.abstasks.TaskMetadata import TaskMetadata

from ....abstasks.AbsTaskSTS import AbsTaskSTS


class SickrSTS(AbsTaskSTS):
    metadata = TaskMetadata(
        name="SICK-R",
        dataset={
            "path": "mteb/sickr-sts",
            "revision": "20a6d6f312dd54037fe07a32d58e5e168867909d",
        },
        description="Semantic Textual Similarity SICK-R dataset as described here:",
        reference="https://aclanthology.org/2020.lrec-1.207",
        type="STS",
        category="s2s",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="cosine_spearman",
        date=None,
        domains=None,
        task_subtypes=None,
        license=None,
        annotations_creators=None,
        dialect=None,
        sample_creation=None,
        bibtex_citation="""@inproceedings{dadas-etal-2020-evaluation,
    title = "Evaluation of Sentence Representations in {P}olish",
    author = "Dadas, Slawomir  and
      Pere{\l}kiewicz, Micha{\l}  and
      Po{\'s}wiata, Rafa{\l}",
    editor = "Calzolari, Nicoletta  and
      B{\'e}chet, Fr{\'e}d{\'e}ric  and
      Blache, Philippe  and
      Choukri, Khalid  and
      Cieri, Christopher  and
      Declerck, Thierry  and
      Goggi, Sara  and
      Isahara, Hitoshi  and
      Maegaard, Bente  and
      Mariani, Joseph  and
      Mazo, H{\'e}l{\`e}ne  and
      Moreno, Asuncion  and
      Odijk, Jan  and
      Piperidis, Stelios",
    booktitle = "Proceedings of the Twelfth Language Resources and Evaluation Conference",
    month = may,
    year = "2020",
    address = "Marseille, France",
    publisher = "European Language Resources Association",
    url = "https://aclanthology.org/2020.lrec-1.207",
    pages = "1674--1680",
    abstract = "Methods for learning sentence representations have been actively developed in recent years. However, the lack of pre-trained models and datasets annotated at the sentence level has been a problem for low-resource languages such as Polish which led to less interest in applying these methods to language-specific tasks. In this study, we introduce two new Polish datasets for evaluating sentence embeddings and provide a comprehensive evaluation of eight sentence representation methods including Polish and multilingual models. We consider classic word embedding models, recently developed contextual embeddings and multilingual sentence encoders, showing strengths and weaknesses of specific approaches. We also examine different methods of aggregating word vectors into a single sentence vector.",
    language = "English",
    ISBN = "979-10-95546-34-4",
}""",
        descriptive_stats={"n_samples": None, "avg_character_length": None},
    )

    @property
    def metadata_dict(self) -> dict[str, str]:
        metadata_dict = super().metadata_dict
        metadata_dict["min_score"] = 0
        metadata_dict["max_score"] = 5
        return metadata_dict



from __future__ import annotations

import itertools

from datasets import Dataset, DatasetDict

from mteb.abstasks.AbsTaskClusteringFast import AbsTaskClusteringFast
from mteb.abstasks.TaskMetadata import TaskMetadata

N_SAMPLES = 2048


def split_labels(record: dict) -> dict:
    record["labels"] = record["labels"].split(".")
    return record


class ArXivHierarchicalClusteringP2P(AbsTaskClusteringFast):
    metadata = TaskMetadata(
        name="ArXivHierarchicalClusteringP2P",
        description="Clustering of titles+abstract from arxiv. Clustering of 30 sets, either on the main or secondary category",
        reference="https://www.kaggle.com/Cornell-University/arxiv",
        dataset={
            "path": "mteb/arxiv-clustering-p2p",
            "revision": "0bbdb47bcbe3a90093699aefeed338a0f28a7ee8",
        },
        type="Clustering",
        category="p2p",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="v_measure",
        date=("1991-01-01", "2021-01-01"),  # 1991-01-01 is the first arxiv paper
        domains=["Academic", "Written"],
        task_subtypes=[],
        license="cc0-1.0",
        annotations_creators="derived",
        dialect=["Thematic clustering"],
        sample_creation="found",
        bibtex_citation="",
        descriptive_stats={
            "n_samples": {"test": N_SAMPLES},
            "test": {
                "num_samples": 2048,
                "average_text_length": 1008.439453125,
                "average_labels_per_text": 1.46337890625,
                "unique_labels": 129,
                "labels": {
                    "cs": {"count": 356},
                    "math": {"count": 381},
                    "OC": {"count": 11},
                    "hep-lat": {"count": 13},
                    "hep": {"count": 98},
                    "astro-ph": {"count": 213},
                    "eess": {"count": 76},
                    "quant-ph": {"count": 135},
                    "DC": {"count": 5},
                    "cond-mat": {"count": 274},
                    "hep-th": {"count": 66},
                    "SP": {"count": 33},
                    "hep-ph": {"count": 69},
                    "FA": {"count": 6},
                    "nucl-th": {"count": 17},
                    "q-bio": {"count": 80},
                    "HE": {"count": 22},
                    "HC": {"count": 2},
                    "stat": {"count": 60},
                    "ML": {"count": 16},
                    "IV": {"count": 13},
                    "stat-mech": {"count": 47},
                    "DS": {"count": 14},
                    "ME": {"count": 12},
                    "CC": {"count": 2},
                    "mtrl-sci": {"count": 22},
                    "PE": {"count": 16},
                    "NT": {"count": 11},
                    "SC": {"count": 6},
                    "AG": {"count": 13},
                    "physics": {"count": 81},
                    "ins-det": {"count": 9},
                    "GA": {"count": 18},
                    "BM": {"count": 6},
                    "GN": {"count": 17},
                    "NA": {"count": 15},
                    "app-ph": {"count": 7},
                    "RT": {"count": 6},
                    "other": {"count": 37},
                    "soft": {"count": 15},
                    "CO": {"count": 33},
                    "supr-con": {"count": 21},
                    "chem-ph": {"count": 3},
                    "DM": {"count": 2},
                    "MN": {"count": 12},
                    "q-fin": {"count": 27},
                    "PM": {"count": 2},
                    "AP": {"count": 27},
                    "gr-qc": {"count": 15},
                    "quant-gas": {"count": 8},
                    "mes-hall": {"count": 33},
                    "IT": {"count": 19},
                    "SI": {"count": 6},
                    "SG": {"count": 3},
                    "bio-ph": {"count": 2},
                    "SR": {"count": 16},
                    "soc-ph": {"count": 5},
                    "hep-ex": {"count": 15},
                    "DG": {"count": 11},
                    "NE": {"count": 5},
                    "CR": {"count": 6},
                    "CL": {"count": 12},
                    "RM": {"count": 3},
                    "econ": {"count": 17},
                    "nlin": {"count": 5},
                    "PS": {"count": 1},
                    "LG": {"count": 26},
                    "QA": {"count": 9},
                    "str-el": {"count": 26},
                    "CV": {"count": 34},
                    "MF": {"count": 6},
                    "IM": {"count": 7},
                    "EM": {"count": 6},
                    "TH": {"count": 5},
                    "PR": {"count": 20},
                    "AT": {"count": 4},
                    "OA": {"count": 4},
                    "CP": {"count": 6},
                    "LO": {"count": 14},
                    "flu-dyn": {"count": 6},
                    "atom-ph": {"count": 8},
                    "class-ph": {"count": 1},
                    "SY": {"count": 20},
                    "IR": {"count": 1},
                    "plasm-ph": {"count": 8},
                    "CE": {"count": 2},
                    "AO": {"count": 1},
                    "comp-ph": {"count": 3},
                    "optics": {"count": 12},
                    "MG": {"count": 4},
                    "ST": {"count": 6},
                    "nucl-ex": {"count": 6},
                    "CY": {"count": 9},
                    "ao-ph": {"count": 2},
                    "DB": {"count": 1},
                    "math-ph": {"count": 10},
                    "NC": {"count": 13},
                    "GT": {"count": 11},
                    "TO": {"count": 2},
                    "AI": {"count": 9},
                    "NI": {"count": 2},
                    "gen-ph": {"count": 4},
                    "OT": {"count": 4},
                    "SD": {"count": 2},
                    "dis-nn": {"count": 4},
                    "RO": {"count": 7},
                    "CA": {"count": 6},
                    "FL": {"count": 1},
                    "SE": {"count": 5},
                    "EP": {"count": 9},
                    "hist-ph": {"count": 1},
                    "QM": {"count": 9},
                    "ed-ph": {"count": 2},
                    "GR": {"count": 4},
                    "MS": {"count": 1},
                    "CD": {"count": 1},
                    "ET": {"count": 1},
                    "acc-ph": {"count": 5},
                    "AC": {"count": 2},
                    "OH": {"count": 1},
                    "EC": {"count": 2},
                    "DL": {"count": 1},
                    "AS": {"count": 3},
                    "geo-ph": {"count": 2},
                    "CG": {"count": 3},
                    "CB": {"count": 1},
                    "AR": {"count": 1},
                    "TR": {"count": 1},
                    "atm-clus": {"count": 1},
                },
            },
        },
    )

    def dataset_transform(self):
        ds = {}
        for split in self.metadata.eval_splits:
            labels = list(itertools.chain.from_iterable(self.dataset[split]["labels"]))
            sentences = list(
                itertools.chain.from_iterable(self.dataset[split]["sentences"])
            )
            ds[split] = Dataset.from_dict({"labels": labels, "sentences": sentences})
        self.dataset = DatasetDict(ds)
        self.dataset = self.dataset.map(split_labels)
        self.dataset["test"] = self.dataset["test"].train_test_split(
            test_size=N_SAMPLES, seed=self.seed
        )["test"]


class ArXivHierarchicalClusteringS2S(AbsTaskClusteringFast):
    metadata = TaskMetadata(
        name="ArXivHierarchicalClusteringS2S",
        description="Clustering of titles from arxiv. Clustering of 30 sets, either on the main or secondary category",
        reference="https://www.kaggle.com/Cornell-University/arxiv",
        dataset={
            "path": "mteb/arxiv-clustering-s2s",
            "revision": "b73bd54100e5abfa6e3a23dcafb46fe4d2438dc3",
        },
        type="Clustering",
        category="p2p",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="v_measure",
        date=("1991-01-01", "2021-01-01"),  # 1991-01-01 is the first arxiv paper
        domains=["Academic", "Written"],
        task_subtypes=["Thematic clustering"],
        license="cc0-1.0",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation="",
        descriptive_stats={
            "n_samples": {"test": N_SAMPLES},
            "avg_character_length": {"test": 1009.98},
        },
    )

    def dataset_transform(self):
        ds = {}
        for split in self.metadata.eval_splits:
            labels = list(itertools.chain.from_iterable(self.dataset[split]["labels"]))
            sentences = list(
                itertools.chain.from_iterable(self.dataset[split]["sentences"])
            )
            ds[split] = Dataset.from_dict({"labels": labels, "sentences": sentences})
        self.dataset = DatasetDict(ds)
        self.dataset = self.dataset.map(split_labels)
        self.dataset["test"] = self.dataset["test"].train_test_split(
            test_size=N_SAMPLES, seed=self.seed
        )["test"]



from __future__ import annotations

from functools import partial

import torch

from mteb.model_meta import ModelMeta

from .e5_models import E5_PAPER_RELEASE_DATE, XLMR_LANGUAGES
from .instructions import task_to_instruction

MISTRAL_LANGUAGES = ["eng_Latn", "fra_Latn", "deu_Latn", "ita_Latn", "spa_Latn"]


def e5_instruction(instruction: str) -> str:
    return f"Instruct: {instruction}\nQuery: "


def e5_loader(**kwargs):
    try:
        from gritlm import GritLM
    except ImportError:
        raise ImportError(
            "Please install `pip install gritlm` to use E5 Instruct models."
        )

    class E5InstructWrapper(GritLM):
        def encode(self, *args, **kwargs):
            if "prompt_name" in kwargs:
                if "instruction" in kwargs:
                    raise ValueError(
                        "Cannot specify both `prompt_name` and `instruction`."
                    )
                instruction = task_to_instruction(
                    kwargs.pop("prompt_name"), kwargs.pop("is_query", True)
                )
            else:
                instruction = kwargs.pop("instruction", "")
            if instruction:
                kwargs["instruction"] = e5_instruction(instruction)
            return super().encode(*args, **kwargs)

        def encode_corpus(self, *args, **kwargs):
            kwargs["is_query"] = False
            return super().encode_corpus(*args, **kwargs)

    return E5InstructWrapper(**kwargs)


e5_instruct = ModelMeta(
    loader=partial(
        e5_loader,
        model_name_or_path="intfloat/multilingual-e5-large-instruct",
        attn="cccc",
        pooling_method="mean",
        mode="embedding",
        torch_dtype=torch.float16,
        normalized=True,
    ),
    name="intfloat/multilingual-e5-large-instruct",
    languages=XLMR_LANGUAGES,
    open_source=True,
    revision="baa7be480a7de1539afce709c8f13f833a510e0a",
    release_date=E5_PAPER_RELEASE_DATE,
)

e5_mistral = ModelMeta(
    loader=partial(
        e5_loader,
        model_name_or_path="intfloat/e5-mistral-7b-instruct",
        attn="cccc",
        pooling_method="lasttoken",
        mode="embedding",
        torch_dtype=torch.float16,
        # The ST script does not normalize while the HF one does so unclear what to do
        # https://huggingface.co/intfloat/e5-mistral-7b-instruct#transformers
        normalized=True,
    ),
    name="intfloat/e5-mistral-7b-instruct",
    languages=MISTRAL_LANGUAGES,
    open_source=True,
    revision="07163b72af1488142a360786df853f237b1a3ca1",
    release_date=E5_PAPER_RELEASE_DATE,
)



from __future__ import annotations

import datasets

from mteb.abstasks.MultilingualTask import MultilingualTask
from mteb.abstasks.TaskMetadata import TaskMetadata

from ....abstasks.AbsTaskRetrieval import AbsTaskRetrieval

_EVAL_SPLIT = "test"

_LANGS = {
    # <iso_639_3>-<ISO_15924>
    "arabic": ["ara-Arab"],
    "chinese": ["zho-Hans"],
    "english": ["eng-Latn"],
    "french": ["fra-Latn"],
    "korean": ["kor-Hang"],
    "russian": ["rus-Cyrl"],
    "spanish": ["spa-Latn"],
    "vietnamese": ["vie-Latn"],
}


def _load_publichealthqa_data(
    path: str, langs: list, split: str, cache_dir: str = None, revision: str = None
):
    queries = {lang: {split: {}} for lang in langs}
    corpus = {lang: {split: {}} for lang in langs}
    relevant_docs = {lang: {split: {}} for lang in langs}

    for lang in langs:
        data = datasets.load_dataset(
            path,
            lang,
            split=split,
            cache_dir=cache_dir,
            revision=revision,
        )
        question_ids = {
            question: _id for _id, question in enumerate(set(data["question"]))
        }
        answer_ids = {answer: _id for _id, answer in enumerate(set(data["answer"]))}

        for row in data:
            question = row["question"]
            answer = row["answer"]
            query_id = f"Q{question_ids[question]}"
            queries[lang][split][query_id] = question
            doc_id = f"D{answer_ids[answer]}"
            corpus[lang][split][doc_id] = {"text": answer}
            if query_id not in relevant_docs[lang][split]:
                relevant_docs[lang][split][query_id] = {}
            relevant_docs[lang][split][query_id][doc_id] = 1

    corpus = datasets.DatasetDict(corpus)
    queries = datasets.DatasetDict(queries)
    relevant_docs = datasets.DatasetDict(relevant_docs)

    return corpus, queries, relevant_docs


class PublicHealthQARetrieval(MultilingualTask, AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="PublicHealthQA",
        description="A multilingual dataset for public health question answering, based on FAQ sourced from CDC and WHO.",
        dataset={
            "path": "xhluca/publichealth-qa",
            "revision": "main",
        },
        type="Retrieval",
        category="s2p",
        modalities=["text"],
        eval_splits=[_EVAL_SPLIT],
        eval_langs=_LANGS,
        main_score="ndcg_at_10",
        reference="https://huggingface.co/datasets/xhluca/publichealth-qa",
        date=("2020-01-01", "2020-04-15"),
        domains=["Medical", "Government", "Web", "Written"],
        task_subtypes=["Question answering"],
        license="cc-by-nc-sa-3.0",
        annotations_creators="derived",
        dialect=[],
        sample_creation="found",
        bibtex_citation="""
@misc {xing_han_lu_2024,
	author       = { {Xing Han Lu} },
	title        = { publichealth-qa (Revision 3b67b6b) },
	year         = 2024,
	url          = { https://huggingface.co/datasets/xhluca/publichealth-qa },
	doi          = { 10.57967/hf/2247 },
	publisher    = { Hugging Face }
}
""",
        descriptive_stats={
            "n_samples": {"test": 888},
            "avg_character_length": {
                "test": {
                    "arabic": {
                        "average_document_length": 836.8850574712644,
                        "average_query_length": 79.84883720930233,
                        "num_documents": 87,
                        "num_queries": 87,
                        "average_relevant_docs_per_query": 1.0,
                    },
                    "chinese": {
                        "average_document_length": 239.58282208588957,
                        "average_query_length": 24.828220858895705,
                        "num_documents": 163,
                        "num_queries": 163,
                        "average_relevant_docs_per_query": 1.0,
                    },
                    "english": {
                        "average_document_length": 799.3430232558139,
                        "average_query_length": 71.78488372093024,
                        "num_documents": 172,
                        "num_queries": 172,
                        "average_relevant_docs_per_query": 1.0,
                    },
                    "french": {
                        "average_document_length": 1021.6823529411764,
                        "average_query_length": 101.88235294117646,
                        "num_documents": 85,
                        "num_queries": 85,
                        "average_relevant_docs_per_query": 1.0,
                    },
                    "korean": {
                        "average_document_length": 339.0,
                        "average_query_length": 36.90909090909091,
                        "num_documents": 77,
                        "num_queries": 77,
                        "average_relevant_docs_per_query": 1.0,
                    },
                    "russian": {
                        "average_document_length": 985.1076923076923,
                        "average_query_length": 85.2,
                        "num_documents": 65,
                        "num_queries": 65,
                        "average_relevant_docs_per_query": 1.0,
                    },
                    "spanish": {
                        "average_document_length": 941.1666666666666,
                        "average_query_length": 84.67901234567901,
                        "num_documents": 162,
                        "num_queries": 162,
                        "average_relevant_docs_per_query": 1.0,
                    },
                    "vietnamese": {
                        "average_document_length": 704.5454545454545,
                        "average_query_length": 71.83116883116882,
                        "num_documents": 77,
                        "num_queries": 77,
                        "average_relevant_docs_per_query": 1.0,
                    },
                }
            },
        },
    )

    def load_data(self, **kwargs):
        if self.data_loaded:
            return

        self.corpus, self.queries, self.relevant_docs = _load_publichealthqa_data(
            path=self.metadata_dict["dataset"]["path"],
            langs=self.hf_subsets,
            split=self.metadata_dict["eval_splits"][0],
            cache_dir=kwargs.get("cache_dir", None),
            revision=self.metadata_dict["dataset"]["revision"],
        )

        self.data_loaded = True



from __future__ import annotations

import logging
from collections import Counter, defaultdict
from typing import Any

import numpy as np
import tqdm

from mteb.encoder_interface import Encoder

from ..evaluation.evaluators import (
    kNNClassificationEvaluator,
    kNNClassificationEvaluatorPytorch,
    logRegClassificationEvaluator,
)
from ..load_results.mteb_results import HFSubset, ScoresDict
from .AbsTask import AbsTask, DescriptiveStatistics

logger = logging.getLogger(__name__)


class ClassificationDescriptiveStatistics(DescriptiveStatistics):
    """Descriptive statistics for Classification

    Attributes:
      num_samples: number of samples in the dataset.
      average_text_length: Average length of text
      unique_labels: Number of unique labels
      labels: dict of label frequencies
    """

    num_samples: int
    average_text_length: float
    unique_labels: int
    labels: dict[str, dict[str, int]]


class AbsTaskClassification(AbsTask):
    """Abstract class for kNN classification tasks
    The similarity is computed between pairs and the results are ranked.

    self.load_data() must generate a huggingface dataset with a split matching self.metadata_dict["eval_splits"], and assign it to self.dataset. It
    must contain the following columns:
        text: str
        label: int
    """

    def __init__(
        self,
        method: str = "logReg",
        n_experiments: int | None = None,
        samples_per_label: int | None = None,
        k: int = 3,
        **kwargs,
    ):
        super().__init__(**kwargs)
        self.method = method

        # Bootstrap parameters
        self.n_experiments: int = (  # type: ignore
            n_experiments
            if n_experiments is not None
            else self.metadata_dict.get("n_experiments", 10)
        )
        self.samples_per_label: int = (  # type: ignore
            samples_per_label
            if samples_per_label is not None
            else self.metadata_dict.get("samples_per_label", 8)
        )

        # kNN parameters
        self.k = k

    def _add_main_score(self, scores: dict[HFSubset, ScoresDict]) -> None:
        scores["main_score"] = scores[self.metadata.main_score]

    def evaluate(
        self,
        model,
        eval_split: str = "test",
        train_split: str = "train",
        *,
        encode_kwargs: dict[str, Any] = {},
        **kwargs,
    ) -> dict[HFSubset, ScoresDict]:
        if not self.data_loaded:
            self.load_data()

        scores = {}
        hf_subsets = list(self.dataset) if self.is_multilingual else ["default"]

        for hf_subset in hf_subsets:
            logger.info(
                f"\nTask: {self.metadata.name}, split: {eval_split}, subset: {hf_subset}. Running..."
            )

            if hf_subset not in self.dataset and hf_subset == "default":
                ds = self.dataset
            else:
                ds = self.dataset[hf_subset]
            scores[hf_subset] = self._evaluate_subset(
                model,
                ds,
                eval_split,
                train_split,
                encode_kwargs=encode_kwargs,
                **kwargs,
            )
            self._add_main_score(scores[hf_subset])

        return scores

    def _evaluate_subset(
        self,
        model: Encoder,
        dataset,
        eval_split: str = "test",
        train_split: str = "train",
        encode_kwargs: dict[str, Any] = {},
        **kwargs,
    ) -> ScoresDict:
        train_split = dataset[train_split]
        eval_split = dataset[eval_split]
        params = {"k": self.k}
        params.update(kwargs)

        scores = []
        test_cache, idxs = (
            None,
            None,
        )  # we store idxs to make the shuffling reproducible
        for i in range(self.n_experiments):
            logger.info(
                "=" * 10 + f" Experiment {i+1}/{self.n_experiments} " + "=" * 10
            )
            # Bootstrap `self.samples_per_label` samples per label for each split
            X_sampled, y_sampled, idxs = self._undersample_data(
                train_split["text"],  # type: ignore
                train_split["label"],  # type: ignore
                self.samples_per_label,
                idxs,
            )

            if self.method == "kNN":
                evaluator = kNNClassificationEvaluator(
                    X_sampled,
                    y_sampled,
                    eval_split["text"],  # type: ignore
                    eval_split["label"],  # type: ignore
                    task_name=self.metadata.name,
                    encode_kwargs=encode_kwargs,
                    **params,
                )
            elif self.method == "kNN-pytorch":
                evaluator = kNNClassificationEvaluatorPytorch(
                    X_sampled,
                    y_sampled,
                    eval_split["text"],  # type: ignore
                    eval_split["label"],  # type: ignore
                    task_name=self.metadata.name,
                    encode_kwargs=encode_kwargs,
                    **params,
                )
            elif self.method == "logReg":
                evaluator = logRegClassificationEvaluator(
                    X_sampled,
                    y_sampled,
                    eval_split["text"],  # type: ignore
                    eval_split["label"],  # type: ignore
                    task_name=self.metadata.name,
                    encode_kwargs=encode_kwargs,
                    **params,
                )
            else:
                raise ValueError(f"Method {self.method} not supported")

            scores_exp, test_cache = evaluator(model, test_cache=test_cache)
            scores.append(scores_exp)

        avg_scores: dict[str, Any] = {
            k: np.mean([s[k] for s in scores]) for k in scores[0].keys()
        }
        avg_scores["scores_per_experiment"] = scores
        return avg_scores

    def _undersample_data(self, X, y, samples_per_label: int, idxs=None):
        """Undersample data to have samples_per_label samples of each label"""
        X_sampled = []
        y_sampled = []
        if idxs is None:
            idxs = np.arange(len(y))
        np.random.shuffle(idxs)
        label_counter = defaultdict(int)
        for i in idxs:
            if label_counter[y[i]] < samples_per_label:
                X_sampled.append(X[i])
                y_sampled.append(y[i])
                label_counter[y[i]] += 1
        return X_sampled, y_sampled, idxs

    def calculate_metadata_metrics(
        self,
    ) -> dict[
        str,
        ClassificationDescriptiveStatistics
        | dict[str, ClassificationDescriptiveStatistics],
    ]:
        self.load_data()

        # same function from parent class, but added explicitly train to splits

        all_details = {}
        pbar_split = tqdm.tqdm(
            self.metadata.eval_splits + ["train"], desc="Processing Splits..."
        )
        for split in pbar_split:
            pbar_split.set_postfix_str(f"Split: {split}")
            print(f"Processing metadata for split {split}")
            if self.is_multilingual:
                all_details[split] = self._calculate_metrics_from_split(
                    split, compute_overall=True
                )
                all_details[split]["hf_subset_descriptive_stats"] = {}

                pbar_subset = tqdm.tqdm(
                    self.metadata.eval_langs, desc="Processing Languages..."
                )
                for hf_subset in pbar_subset:
                    pbar_subset.set_postfix_str(f"Language: {hf_subset}")
                    print(f"Processing metadata for language {hf_subset}")
                    split_details = self._calculate_metrics_from_split(split, hf_subset)
                    all_details[split][hf_subset] = split_details
            else:
                split_details = self._calculate_metrics_from_split(split)
                all_details[split] = split_details

        return all_details

    def _calculate_metrics_from_split(
        self, split: str, hf_subset: str | None = None, compute_overall: bool = False
    ) -> ClassificationDescriptiveStatistics:
        if hf_subset:
            text = self.dataset[hf_subset][split]["text"]
            label = self.dataset[hf_subset][split]["label"]
        elif compute_overall:
            text = []
            label = []
            for hf_subset in self.metadata.eval_langs:
                text.extend(self.dataset[hf_subset][split]["text"])
                label.extend(self.dataset[hf_subset][split]["label"])
        else:
            text = self.dataset[split]["text"]
            label = self.dataset[split]["label"]

        total_text_len = sum([len(t) for t in text])
        label_count = Counter(label)
        return ClassificationDescriptiveStatistics(
            num_samples=len(text),
            average_text_length=total_text_len / len(text),
            unique_labels=len(label_count),
            labels={
                str(label): {"count": count} for label, count in label_count.items()
            },
        )



from __future__ import annotations

from mteb.abstasks.AbsTaskSummarization import AbsTaskSummarization
from mteb.abstasks.TaskMetadata import TaskMetadata
from mteb.evaluation.evaluators.SummarizationEvaluator import (
    DeprecatedSummarizationEvaluator,
)


class SummEvalFrSummarization(AbsTaskSummarization):
    superseded_by = "SummEvalFrSummarization.v2"
    evalutor = DeprecatedSummarizationEvaluator
    metadata = TaskMetadata(
        name="SummEvalFr",
        description="News Article Summary Semantic Similarity Estimation translated from english to french with DeepL.",
        reference="https://github.com/Yale-LILY/SummEval",
        dataset={
            "path": "lyon-nlp/summarization-summeval-fr-p2p",
            "revision": "b385812de6a9577b6f4d0f88c6a6e35395a94054",
        },
        type="Summarization",
        category="p2p",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["fra-Latn"],
        main_score="cosine_spearman",
        date=("2016-01-01", "2016-12-31"),
        domains=["News", "Written"],
        task_subtypes=[],
        license="mit",
        annotations_creators="human-annotated",
        dialect=[],
        sample_creation="machine-translated",
        bibtex_citation="""@article{fabbri2020summeval,
  title={SummEval: Re-evaluating Summarization Evaluation},
  author={Fabbri, Alexander R and Kry{\'s}ci{\'n}ski, Wojciech and McCann, Bryan and Xiong, Caiming and Socher, Richard and Radev, Dragomir},
  journal={arXiv preprint arXiv:2007.12626},
  year={2020}
}""",
        descriptive_stats={
            "n_samples": {"test": 2800},
            "avg_character_length": {"test": 407.1},
        },
    )

    @property
    def metadata_dict(self) -> dict[str, str]:
        metadata_dict = super().metadata_dict
        metadata_dict["min_score"] = 0
        metadata_dict["max_score"] = 5

        return metadata_dict


class SummEvalFrSummarizationv2(AbsTaskSummarization):
    metadata = TaskMetadata(
        name="SummEvalFrSummarization.v2",
        description="News Article Summary Semantic Similarity Estimation translated from english to french with DeepL. This version fixes a bug in the evaluation script that caused the main score to be computed incorrectly.",
        reference="https://github.com/Yale-LILY/SummEval",
        dataset={
            "path": "lyon-nlp/summarization-summeval-fr-p2p",
            "revision": "b385812de6a9577b6f4d0f88c6a6e35395a94054",
        },
        type="Summarization",
        category="p2p",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["fra-Latn"],
        main_score="cosine_spearman",
        date=("2016-01-01", "2016-12-31"),
        domains=["News", "Written"],
        task_subtypes=[],
        license="mit",
        annotations_creators="human-annotated",
        dialect=[],
        sample_creation="machine-translated",
        bibtex_citation="""@article{fabbri2020summeval,
  title={SummEval: Re-evaluating Summarization Evaluation},
  author={Fabbri, Alexander R and Kry{\'s}ci{\'n}ski, Wojciech and McCann, Bryan and Xiong, Caiming and Socher, Richard and Radev, Dragomir},
  journal={arXiv preprint arXiv:2007.12626},
  year={2020}
}""",
        descriptive_stats={
            "n_samples": {"test": 2800},
            "avg_character_length": {"test": 407.1},
        },
    )

    @property
    def metadata_dict(self) -> dict[str, str]:
        metadata_dict = super().metadata_dict
        metadata_dict["min_score"] = 0
        metadata_dict["max_score"] = 5

        return metadata_dict



from __future__ import annotations

from mteb.abstasks.TaskMetadata import TaskMetadata

from ....abstasks.AbsTaskRetrieval import AbsTaskRetrieval


class LegalBenchConsumerContractsQA(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="LegalBenchConsumerContractsQA",
        description="The dataset includes questions and answers related to contracts.",
        reference="https://huggingface.co/datasets/nguha/legalbench/viewer/consumer_contracts_qa",
        dataset={
            "path": "mteb/legalbench_consumer_contracts_qa",
            "revision": "b23590301ec94e8087e2850b21d43d4956b1cca9",
        },
        type="Retrieval",
        category="s2p",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_10",
        date=None,
        domains=["Legal", "Written"],
        task_subtypes=["Question answering"],
        license="cc-by-nc-4.0",
        annotations_creators="derived",
        dialect=None,
        sample_creation="found",
        bibtex_citation="""@article{koreeda2021contractnli,
  title={ContractNLI: A dataset for document-level natural language inference for contracts},
  author={Koreeda, Yuta and Manning, Christopher D},
  journal={arXiv preprint arXiv:2110.01799},
  year={2021}
  }

  @article{hendrycks2021cuad,
  title={Cuad: An expert-annotated nlp dataset for legal contract review},
  author={Hendrycks, Dan and Burns, Collin and Chen, Anya and Ball, Spencer},
  journal={arXiv preprint arXiv:2103.06268},
  year={2021}
}""",
        descriptive_stats={
            "n_samples": None,
            "avg_character_length": {
                "test": {
                    "average_document_length": 2745.8246753246754,
                    "average_query_length": 92.4090909090909,
                    "num_documents": 154,
                    "num_queries": 396,
                    "average_relevant_docs_per_query": 1.0,
                }
            },
        },
    )



from __future__ import annotations

from mteb.abstasks.TaskMetadata import TaskMetadata

from ....abstasks.AbsTaskRetrieval import AbsTaskRetrieval


class QuoraRetrieval(AbsTaskRetrieval):
    ignore_identical_ids = True

    metadata = TaskMetadata(
        name="QuoraRetrieval",
        dataset={
            "path": "mteb/quora",
            "revision": "e4e08e0b7dbe3c8700f0daef558ff32256715259",
        },
        description=(
            "QuoraRetrieval is based on questions that are marked as duplicates on the Quora platform. Given a"
            + " question, find other (duplicate) questions."
        ),
        reference="https://quoradata.quora.com/First-Quora-Dataset-Release-Question-Pairs",
        type="Retrieval",
        category="s2s",
        modalities=["text"],
        eval_splits=["dev", "test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_10",
        date=None,
        domains=None,
        task_subtypes=None,
        license=None,
        annotations_creators=None,
        dialect=None,
        sample_creation=None,
        bibtex_citation="""@misc{quora-question-pairs,
    author = {DataCanary, hilfialkaff, Lili Jiang, Meg Risdal, Nikhil Dandekar, tomtung},
    title = {Quora Question Pairs},
    publisher = {Kaggle},
    year = {2017},
    url = {https://kaggle.com/competitions/quora-question-pairs}
}""",
        descriptive_stats={
            "n_samples": None,
            "avg_character_length": {
                "dev": {
                    "average_document_length": 62.158154708747425,
                    "average_query_length": 51.5342,
                    "num_documents": 522931,
                    "num_queries": 5000,
                    "average_relevant_docs_per_query": 1.5252,
                },
                "test": {
                    "average_document_length": 62.158154708747425,
                    "average_query_length": 51.5396,
                    "num_documents": 522931,
                    "num_queries": 10000,
                    "average_relevant_docs_per_query": 1.5675,
                },
            },
        },
    )


class QuoraRetrievalHardNegatives(AbsTaskRetrieval):
    ignore_identical_ids = True

    metadata = TaskMetadata(
        name="QuoraRetrievalHardNegatives",
        dataset={
            "path": "mteb/QuoraRetrieval_test_top_250_only_w_correct-v2",
            "revision": "907a33577e9506221d3ba20f5a851b7c3f8dc6d3",
        },
        description=(
            "QuoraRetrieval is based on questions that are marked as duplicates on the Quora platform. Given a"
            + " question, find other (duplicate) questions. The hard negative version has been created by pooling the 250 top documents per query from BM25, e5-multilingual-large and e5-mistral-instruct."
        ),
        reference="https://quoradata.quora.com/First-Quora-Dataset-Release-Question-Pairs",
        type="Retrieval",
        category="s2s",
        modalities=["text"],
        eval_splits=["test"],
        eval_langs=["eng-Latn"],
        main_score="ndcg_at_10",
        date=None,
        domains=None,
        task_subtypes=None,
        license=None,
        annotations_creators=None,
        dialect=None,
        sample_creation=None,
        bibtex_citation="""@misc{quora-question-pairs,
    author = {DataCanary, hilfialkaff, Lili Jiang, Meg Risdal, Nikhil Dandekar, tomtung},
    title = {Quora Question Pairs},
    publisher = {Kaggle},
    year = {2017},
    url = {https://kaggle.com/competitions/quora-question-pairs}
}""",
        descriptive_stats={
            "n_samples": {"test": 1000},
            "avg_character_length": {
                "test": {
                    "average_document_length": 58.96963812985781,
                    "average_query_length": 51.228,
                    "num_documents": 177163,
                    "num_queries": 1000,
                    "average_relevant_docs_per_query": 1.641,
                }
            },
        },
    )
